From d1e76feeec22c305fda3731faec3890782f09c41 Mon Sep 17 00:00:00 2001
From: Michael Hayes <mike@aiinc.ca>
Date: Tue, 25 Feb 2003 03:11:33 -0800
Subject: [PATCH] [PATCH] Spelling fixes: weird

    wierd -> weird
    wierdo -> weirdo
    wierdness -> weirdness
---
 arch/m68knommu/platform/68360/ints.c  | 2 +-
 arch/v850/kernel/rte_cb_multi.c       | 2 +-
 drivers/net/fec.c                     | 2 +-
 include/asm-i386/mach-visws/cobalt.h  | 2 +-
 include/asm-v850/sim.h                | 2 +-
 include/sound/wavefront.h             | 2 +-
 sound/isa/wavefront/wavefront_fx.c    | 4 ++--
 sound/isa/wavefront/wavefront_synth.c | 6 +++---
 sound/oss/dmasound/dmasound_core.c    | 2 +-
 9 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/arch/m68knommu/platform/68360/ints.c b/arch/m68knommu/platform/68360/ints.c
index c209d406cb99..7885623f2d5c 100644
--- a/arch/m68knommu/platform/68360/ints.c
+++ b/arch/m68knommu/platform/68360/ints.c
@@ -291,7 +291,7 @@ void M68360_do_irq(int vec, struct pt_regs *fp)
 
 	/* unsigned long pend = *(volatile unsigned long *)pquicc->intr_cipr; */
 
-	/* Bugger all that wierdness. For the moment, I seem to know where I came from;
+	/* Bugger all that weirdness. For the moment, I seem to know where I came from;
 	 * vec is passed from a specific ISR, so I'll use it. */
 
 	if (int_irq_list[irq] && int_irq_list[irq]->handler) {
diff --git a/arch/v850/kernel/rte_cb_multi.c b/arch/v850/kernel/rte_cb_multi.c
index 13db814a8919..b423efaf6411 100644
--- a/arch/v850/kernel/rte_cb_multi.c
+++ b/arch/v850/kernel/rte_cb_multi.c
@@ -67,7 +67,7 @@ void __init multi_init (void)
 
 			if ((word & 0xFC0) == 0x780) {
 				/* A `jr' insn, fix up its offset (and yes, the
-				   wierd half-word swapping is intentional). */
+				   weird half-word swapping is intentional). */
 				unsigned short hi = word & 0xFFFF;
 				unsigned short lo = word >> 16;
 				unsigned long udisp22
diff --git a/drivers/net/fec.c b/drivers/net/fec.c
index 0fd6b99eabe4..539e9d434d10 100644
--- a/drivers/net/fec.c
+++ b/drivers/net/fec.c
@@ -828,7 +828,7 @@ static phy_info_t phy_info_lxt970 = {
 /* 
  * I had some nice ideas of running the MDIO faster...
  * The 971 should support 8MHz and I tried it, but things acted really
- * wierd, so 2.5 MHz ought to be enough for anyone...
+ * weird, so 2.5 MHz ought to be enough for anyone...
  */
 
 static void mii_parse_lxt971_sr2(uint mii_reg, struct net_device *dev)
diff --git a/include/asm-i386/mach-visws/cobalt.h b/include/asm-i386/mach-visws/cobalt.h
index 12d623fee6ec..33c36225a042 100644
--- a/include/asm-i386/mach-visws/cobalt.h
+++ b/include/asm-i386/mach-visws/cobalt.h
@@ -60,7 +60,7 @@
 #define	CO_APIC_PCIA_BASE0	0 /* and 1 */	/* slot 0, line 0 */
 #define	CO_APIC_PCIA_BASE123	5 /* and 6 */	/* slot 0, line 1 */
 
-#define	CO_APIC_PIIX4_USB	7		/* this one is wierd */
+#define	CO_APIC_PIIX4_USB	7		/* this one is weird */
 
 /* Lithium PCI Bridge B -- "the one with PIIX4" */
 #define	CO_APIC_PCIB_BASE0	8 /* and 9-12 *//* slot 0, line 0 */
diff --git a/include/asm-v850/sim.h b/include/asm-v850/sim.h
index 41554b9cb650..ae041981a54b 100644
--- a/include/asm-v850/sim.h
+++ b/include/asm-v850/sim.h
@@ -22,7 +22,7 @@
 #define PLATFORM_LONG		"GDB V850E simulator"
 
 
-/* We use a wierd value for RAM, not just 0, for testing purposes.
+/* We use a weird value for RAM, not just 0, for testing purposes.
    These must match the values used in the linker script.  */
 #define RAM_ADDR		0x8F000000
 #define RAM_SIZE		0x01000000
diff --git a/include/sound/wavefront.h b/include/sound/wavefront.h
index 79ff3b4b1da4..c13fd09f0f03 100644
--- a/include/sound/wavefront.h
+++ b/include/sound/wavefront.h
@@ -687,7 +687,7 @@ typedef struct wf_fx_info {
 
 /* Allow direct user-space control over FX memory/coefficient data.
    In theory this could be used to download the FX microprogram,
-   but it would be a little slower, and involve some wierd code.
+   but it would be a little slower, and involve some weird code.
  */
 
 #define WFFX_MEMSET              69
diff --git a/sound/oss/dmasound/dmasound_core.c b/sound/oss/dmasound/dmasound_core.c
index fb36d662a8bc..54b795e2918e 100644
--- a/sound/oss/dmasound/dmasound_core.c
+++ b/sound/oss/dmasound/dmasound_core.c
@@ -1212,7 +1212,7 @@ static int sq_ioctl(struct inode *inode, struct file *file, u_int cmd,
 		return result ;
 		break ;
 	case SNDCTL_DSP_SPEED:
-		/* changing this on the fly will have wierd effects on the sound.
+		/* changing this on the fly will have weird effects on the sound.
 		   Where there are rate conversions implemented in soft form - it
 		   will cause the _ctx_xxx() functions to be substituted.
 		   However, there doesn't appear to be any reason to dis-allow it from
diff --git a/sound/isa/wavefront/wavefront_fx.c b/sound/isa/wavefront/wavefront_fx.c
index 1fce6b4f60a8..01d6647c140e 100644
--- a/sound/isa/wavefront/wavefront_fx.c
+++ b/sound/isa/wavefront/wavefront_fx.c
@@ -227,7 +227,7 @@ snd_wavefront_fx_ioctl (snd_hwdep_t *sdev, struct file *file,
    This code was developed using DOSEMU. The Turtle Beach SETUPSND
    utility was run with I/O tracing in DOSEMU enabled, and a reconstruction
    of the port I/O done, using the Yamaha faxback document as a guide
-   to add more logic to the code. Its really pretty wierd.
+   to add more logic to the code. Its really pretty weird.
 
    There was an alternative approach of just dumping the whole I/O
    sequence as a series of port/value pairs and a simple loop
@@ -692,7 +692,7 @@ snd_wavefront_fx_start (snd_wavefront_t *dev)
 	return (0);
 }
 
 /* wierd stuff, derived from port I/O tracing with dosemu */
 
 static unsigned char page_zero[] __initdata = {
 0x01, 0x7c, 0x00, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf5, 0x00,
@@ -692,7 +692,7 @@ snd_wavefront_fx_start (snd_wavefront_t *dev)
 }
 
-/* wierd stuff, derived from port I/O tracing with dosemu */
+/* weird stuff, derived from port I/O tracing with dosemu */
 
 static unsigned char page_zero[] __initdata = {
diff --git a/sound/isa/wavefront/wavefront_synth.c b/sound/isa/wavefront/wavefront_synth.c
index 650c29871544..9975f2e7619c 100644
--- a/sound/isa/wavefront/wavefront_synth.c
+++ b/sound/isa/wavefront/wavefront_synth.c
@@ -518,7 +518,7 @@ snd_wavefront_cmd (snd_wavefront_t *dev,
 /***********************************************************************
 WaveFront data munging   
 
-Things here are wierd. All data written to the board cannot 
+Things here are weird. All data written to the board cannot 
 have its most significant bit set. Any data item with values 
 potentially > 0x7F (127) must be split across multiple bytes.
 
@@ -527,7 +527,7 @@ the x86 side as 8-32 bit values. Sometimes, we need to munge data
 that is represented on the x86 side as an array of bytes. The most
 efficient approach to handling both cases seems to be to use 2
 different functions for munging and 2 for de-munging. This avoids
-wierd casting and worrying about bit-level offsets.
+weird casting and worrying about bit-level offsets.
 
 **********************************************************************/
 
@@ -1034,7 +1034,7 @@ wavefront_send_sample (snd_wavefront_t *dev,
 	shptr = munge_int32 (*((u32 *) &header->hdr.s.sampleEndOffset),
 			     shptr, 4);
 	
 	/* This one is truly wierd. What kind of wierdo decided that in
 	   a system dominated by 16 and 32 bit integers, they would use
 	   a just 12 bits ?
 	*/
@@ -1034,7 +1034,7 @@ wavefront_send_sample (snd_wavefront_t *dev,
 			     shptr, 4);
 	
-	/* This one is truly wierd. What kind of wierdo decided that in
+	/* This one is truly weird. What kind of weirdo decided that in
 	   a system dominated by 16 and 32 bit integers, they would use
 	   a just 12 bits ?
-- 
2.30.9